@@ -28,7 +28,8 @@ crew_controller_sge <- function(
   tls_enable = NULL,
   tls_config = NULL,
   serialization = NULL,
-  seconds_interval = 0.25,
+  profile = crew::crew_random_name(),
+  seconds_interval = 0.5,
   seconds_timeout = 60,
   seconds_launch = 86400,
   seconds_idle = 300,
@@ -86,6 +87,7 @@ crew_controller_sge <- function(
     tls_enable = tls_enable,
     tls_config = tls_config,
     serialization = serialization,
+    profile = profile,
     seconds_interval = seconds_interval,
     seconds_timeout = seconds_timeout
   )
