@@ -140,9 +140,6 @@ crew_class_launcher_lsf <- R6::R6Class(
   private = list(
     .args_launch = function(script) {
       c("<", shQuote(script))
-    },
-    .args_terminate = function(name) {
-      c("-J", shQuote(name))
     }
   ),
   public = list(
@@ -165,6 +162,9 @@ crew_class_launcher_lsf <- R6::R6Class(
     #' @return Character vector of the lines of the job script.
     #' @param name Character of length 1, name of the job. For inspection
     #'   purposes, you can supply a mock job name.
+    #' @param n Positive integer of length 1, number of crew workers
+    #'   (i.e. cluster jobs) to launch in the current round
+    #'   of auto-scaling.
     #' @examples
     #' if (identical(Sys.getenv("CREW_EXAMPLES"), "true")) {
     #' launcher <- crew_launcher_lsf(
@@ -175,11 +175,11 @@ crew_class_launcher_lsf <- R6::R6Class(
     #' )
     #' launcher$script(name = "my_job_name")
     #' }
-    script = function(name) {
+    script = function(name, n) {
       options <- private$.options_cluster
       c(
         "#!/bin/sh",
-        paste("#BSUB -J", name),
+        sprintf("#BSUB -J \"%s[1-%s]\"", name, n),
         if_any(
           is.null(options$cwd),
           character(0L),
