@@ -62,7 +62,7 @@
 crew_options_sge <- function(
   verbose = FALSE,
   command_submit = as.character(Sys.which("qsub")),
-  command_terminate = as.character(Sys.which("qdel")),
+  command_terminate = NULL,
   script_directory = tempdir(),
   script_lines = character(0L),
   cwd = TRUE,
@@ -94,6 +94,17 @@ crew_options_sge <- function(
     skip_cran = TRUE,
     condition = "message"
   )
+  crew::crew_deprecate(
+    name = "command_terminate",
+    date = "2025-08-26",
+    version = "0.3.8.9001",
+    alternative = paste(
+      "none (no longer needed,
+      c.f. https://github.com/wlandau/crew/issues/236)."
+    ),
+    condition = "message",
+    value = command_terminate
+  )
   if (!is.null(memory_gigabytes_limit)) {
     memory_gigabytes_limit <- memory_gigabytes_limit[1L]
   }
@@ -110,7 +121,6 @@ crew_options_sge <- function(
     list(
       verbose = verbose,
       command_submit = command_submit,
-      command_terminate = command_terminate,
       script_directory = script_directory,
       script_lines = script_lines,
       cwd = cwd,
