@@ -4,7 +4,9 @@ test_that("SGE persistent workers", {
     workers = 1L,
     seconds_launch = 604800,
     seconds_idle = 300,
-    script_lines = paste0("module load R/", getRversion())
+    options_cluster = crew_options_sge(
+      script_lines = paste0("module load R/", getRversion())
+    )
   )
   on.exit(x$terminate())
   x$start()
