@@ -10,13 +10,14 @@ test_that("SLURM minimal", {
   )
   on.exit(controller$terminate())
   controller$start()
-  controller$push( # Should see a job submission message.
+  controller$push(
+    # Should see a job submission message.
     name = "do work",
     command = as.character(Sys.info()["nodename"])
   )
   controller$wait()
   task <- controller$pop()
   expect_false(task$result[[1L]] == as.character(Sys.info()["nodename"]))
-  controller$launcher$terminate() # Should see a job deletion message.
+  controller$launcher$terminate()
   Sys.sleep(5L)
 })
