@@ -11,9 +11,10 @@ test_that("crew_controller_pbs() script() all lines", {
       walltime_hours = 57
     )
   )
-  out <- x$launcher$script(name = "this_job")
+  out <- x$launcher$script(name = "this_job", n = 4L)
   exp <- c(
     "#PBS -N this_job",
+    "#PBS -J 1-4",
     "#PBS -o out_dir/",
     "#PBS -e err_dir/",
     "#PBS -j n",
