@@ -13,9 +13,10 @@ test_that("crew_controller_sge() script() all lines", {
       gpu = 1L
     )
   )
-  out <- x$launcher$script(name = "a_job")
+  out <- x$launcher$script(name = "a_job", n = 8L)
   exp <- c(
     "#$ -N a_job",
+    "#$ -t 1-8",
     "#$ -cwd",
     "#$ -V",
     "#$ -o out_dir/",
