@@ -21,7 +21,7 @@ test_that("valid populated crew_launcher_lsf()", {
 test_that("invalid crew_launcher_lsf(): lsf field", {
   x <- crew_launcher_lsf()
   private <- crew_private(x)
-  private$.options_cluster$cores <- - 1L
+  private$.options_cluster$cores <- -1L
   expect_error(x$validate(), class = "crew_error")
 })
 
@@ -31,12 +31,12 @@ test_that("crew_launcher_lsf() script() nearly empty", {
   )
   lines <- c(
     "#!/bin/sh",
-    "#BSUB -J a_job",
+    "#BSUB -J \"a_job[1-8]\"",
     "#BSUB -cwd /home",
     "#BSUB -o /dev/null",
     "#BSUB -e /dev/null"
   )
-  expect_equal(x$script(name = "a_job"), lines)
+  expect_equal(x$script(name = "a_job", n = 8L), lines)
 })
 
 test_that("crew_launcher_lsf() script() all lines", {
@@ -51,10 +51,10 @@ test_that("crew_launcher_lsf() script() all lines", {
       cores = 2
     )
   )
-  out <- x$script(name = "this_job")
+  out <- x$script(name = "this_job", n = 8L)
   exp <- c(
     "#!/bin/sh",
-    "#BSUB -J this_job",
+    "#BSUB -J \"this_job[1-8]\"",
     "#BSUB -cwd /home",
     "#BSUB -o log1",
     "#BSUB -e log2",
@@ -76,15 +76,6 @@ test_that("crew_launcher_lsf() .args_launch()", {
   )
 })
 
-test_that("crew_launcher_lsf() .args_terminate()", {
-  x <- crew_launcher_lsf()
-  private <- crew_private(x)
-  expect_equal(
-    private$.args_terminate(name = "this_name"),
-    c("-J", shQuote("this_name"))
-  )
-})
-
 test_that("deprecate command_delete", {
   skip_on_cran()
   suppressWarnings(
